# Python Multiplayer

Framework for Client Server Structure in Python.
Is intended to be used for multiplayer games in pygame with this Module.

[pygame-multiplayer](https://github.com/BroCodeAT/python-multiplayer)

----

## Planned features
- [x] Command based Network
- [ ] Threaded Network
- [ ] Async Network